@@ -6,8 +6,16 @@ function (topic, package = NULL, lib.loc = NULL)
     if (!is.character(topic))
         topic <- deparse(topic)[1]
     INDICES <- .find.package(package, lib.loc, verbose = FALSE)
-    file <- index.search(topic, INDICES, "AnIndex", "R-ex")
-    # Neither help, nor example
+    # index.search() will not be visible any more and will have different
+	# arguments in R 2.11... and it is DEPRECATED in R 2.10
+	# => need to use a different code here!!!
+	# This is a temporary hack for svMisc to pass R CMD check on these versions
+	if (exists("index.search", mode= "function")) {
+		file <- index.search(topic, INDICES, "AnIndex", "R-ex")
+	} else {
+		file <- ""
+	}
+	# Neither help, nor example
 	if (file == "") return(c(help = FALSE, example = FALSE))
     packagePath <- dirname(dirname(file))
     if (length(file) > 1) {
