@@ -1,5 +1,6 @@
 "objClear" <-
-function(id = "default") {
+function (id = "default")
+{
     # Clear any reference to a given 'id' object browser
 	id <- as.character(id)[1]	# Make sure id is character
 	if (id == "") id <- "default"
@@ -12,11 +13,10 @@ function(id = "default") {
 	# Also delete corresponding files
 	Root <- objDir()
 	ParsFile = file.path(Root, paste("Pars_", id, ".txt", sep=""))
-	if (file.exists(ParsFile)) unlink(ParsFile) 
+	if (file.exists(ParsFile)) unlink(ParsFile)
 	ListFile = file.path(Root, paste("List_", id, ".txt", sep=""))
 	if (file.exists(ListFile)) unlink(ListFile)
 	MenuFile = file.path(Root, paste("Menu_", id, ".txt", sep=""))
 	if (file.exists(MenuFile)) unlink(MenuFile)
 	return(invisible(TRUE))
 }
-
